@@ -454,7 +454,7 @@ class WireProtocol(object):
             if self.plugin_name == b'Srp':
                 ln = bytes_to_int(data[:2])
                 self.server_salt = data[2:ln+2]
-                self.server_public_key = data[4+ln:]
+                self.server_public_key = hex_to_bytes(data[4+ln:])
 #                print('server_salt=', self.server_salt)
 #                print('server_public_key=', self.server_public_key)
                 self.server_public_key = srp.bytes2long(self.server_public_key)
@@ -463,8 +463,8 @@ class WireProtocol(object):
                                             self.str_to_bytes(self.user),
                                             self.str_to_bytes(self.password),
                                             self.server_salt,
-                                            self.server_public_key,
                                             self.client_public_key,
+                                            self.server_public_key,
                                             self.client_private_key)
 #                print('client_proof=', bytes_to_hex(self.client_proof))
                 # send op_cont_auth
